# Copyright 2014 Budapest University of Technology and Economics (BME IK)
#
# This file is part of CIRCLE Cloud.
#
# CIRCLE is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version.
#
# CIRCLE is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along
# with CIRCLE.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import, unicode_literals

from django.db import models
from django.utils.translation import ugettext_lazy as _

from logging import getLogger

logger = getLogger(__name__)

class AzureBuiltinPublisher(models.Model):
    """
    Azure Built-in publishers (for templates)
    """
    azure_id = models.TextField(verbose_name=_('azure_id'))
    name = models.TextField(verbose_name=_('name'))

    class Meta:
        app_label = 'vm'
        db_table = 'vm_azure_publisher'

    def __unicode__(self):
        return 'azure_publisher-' + str(self.name)

class AzureBuiltinOffer(models.Model):
    """
    Azure Built-in offers (for templates)
    """
    azure_id = models.TextField(verbose_name=_('azure_id'))
    name = models.TextField(verbose_name=_('name'))
    publisher = models.ForeignKey(
        AzureBuiltinPublisher,
        verbose_name=_('azure_publisher'),
        related_name="azure_offer",
        on_delete=models.CASCADE,
    )

    class Meta:
        app_label = 'vm'
        db_table = 'vm_azure_offer'

    def __unicode__(self):
        return 'azure_offer-' + str(self.name)

class AzureBuiltinSKU(models.Model):
    """
    Azure Built-in SKUs (for templates)
    """
    azure_id = models.TextField(verbose_name=_('azure_id'))
    name = models.TextField(verbose_name=_('name'))
    offer = models.ForeignKey(
        AzureBuiltinOffer,
        verbose_name=_('azure_offer'),
        related_name="azure_sku",
        on_delete=models.CASCADE,
    )

    class Meta:
        app_label = 'vm'
        db_table = 'vm_azure_sku'

    def __unicode__(self):
        return 'azure_sku-' + str(self.name)

class AzureBuiltinVersion(models.Model):
    """
    Azure Built-in versions (for templates)
    """
    azure_id = models.TextField(verbose_name=_('azure_id'))
    name = models.TextField(verbose_name=_('name'))
    sku = models.ForeignKey(
        AzureBuiltinSKU,
        verbose_name=_('azure_sku'),
        related_name="azure_version",
        on_delete=models.CASCADE,
    )

    class Meta:
        app_label = 'vm'
        db_table = 'vm_azure_version'

    def __unicode__(self):
        return 'azure_version-' + str(self.name)